@@ -80,7 +80,7 @@ VOID BD_ANS_BCOPY(UCHAR *destination, UCHAR *source, UINT32 length)
 VOID BD_ANS_BZERO(UCHAR *s, UINT32 length)
 {
     while (length--)
-        *s = 0;
+        *s++ = 0;
 }                  
 
 
