@@ -50,7 +50,7 @@
 **********************************************************************/
 
 #include "ans_driver.h"
-
+#include "e100_config.h"
 
 
 /* bd_ans_drv_InitANS()
@@ -73,13 +73,13 @@ bd_ans_drv_InitANS(BOARD_PRIVATE_STRUCT *bps,
     /* set all the required status fields to this driver's 
      * status fields. */
     iANSdata->link_status =
-        (UINT32 *)&(((bd_config_t *)bps)->bddp->cur_link_status);
+        (UINT32 *)&(((bd_config_t *)bps)->cur_link_status);
     
     iANSdata->line_speed  =
-        (UINT32 *)&(((bd_config_t *)bps)->bddp->ans_line_speed);
+        (UINT32 *)&(((bd_config_t *)bps)->ans_line_speed);
     
     iANSdata->duplex      =
-        (UINT32 *)&(((bd_config_t *)bps)->bddp->ans_dplx_mode);
+        (UINT32 *)&(((bd_config_t *)bps)->ans_dplx_mode);
     
     iANSdata->hw_fail   = NULL;
     iANSdata->suspended = NULL;
@@ -111,9 +111,9 @@ bd_ans_drv_UpdateStatus(BOARD_PRIVATE_STRUCT *bps)
      * a status change.
      */
     /* this is done to convert to 32 bit values */
-    ((bd_config_t *)bps)->bddp->ans_line_speed =
+    ((bd_config_t *)bps)->ans_line_speed =
         ((bd_config_t *)bps)->bddp->cur_line_speed;
-    ((bd_config_t *)bps)->bddp->ans_dplx_mode = 
+    ((bd_config_t *)bps)->ans_dplx_mode = 
         ((bd_config_t *)bps)->bddp->cur_dplx_mode;
     return;
 }
@@ -135,7 +135,6 @@ BD_ANS_STATUS
 bd_ans_drv_ConfigureTagging(BOARD_PRIVATE_STRUCT *bdp)
 {
 
-    
     /* no hw action should ne taken to turn general tagging on/off */
     return BD_ANS_SUCCESS;
     
@@ -156,7 +155,6 @@ bd_ans_drv_ConfigureTagging(BOARD_PRIVATE_STRUCT *bdp)
 BD_ANS_STATUS
 bd_ans_drv_ConfigureVlanTable(BOARD_PRIVATE_STRUCT *bps)
 {
-    
     /* this feature is unsupported by 8255x Intel NICs */
     return BD_ANS_FAILURE;
 }
