@@ -49,6 +49,9 @@
 *                                                                     *
 **********************************************************************/
 
+#ifndef _ANS_HW__H_
+#define _ANS_HW__H_
+
 #define BASE_10T        1
 #define BASE_100T4      2
 #define BASE_100TX      4
@@ -92,4 +95,10 @@ typedef struct _ipcb_bits {
 /* function prototypes */
 extern UINT32 bd_ans_hw_AvailableSpeeds(UINT32 phy);
 extern UINT32 bd_ans_hw_flags(BOARD_PRIVATE_STRUCT *bps, UINT16 revid);
+extern __u16 ReadEEprom(bd_config_t *bdp, __u16 reg);
+
+#ifdef IANS_BASE_VLAN_TAGGING
 void bd_ans_hw_ConfigEnableTagging(UINT8 *ConfigBytes, UINT16 rev_id);
+#endif
+
+#endif /* _ANS_HW__H_ */
