@@ -126,7 +126,6 @@ bd_ans_os_Transmit( BOARD_PRIVATE_STRUCT *bps,
     HW_TX_DESCRIPTOR *txd,
     struct sk_buff **skb )
 {
-  
   UINT16 vlan_id;     /* don't know if I really need this */
     IANS_ATTR_HEADER *attr_head = iANSGetTransmitAttributeHeader(*skb);
     iANSsupport_t *iANSdata = ANS_PRIVATE_DATA_FIELD(bps);
@@ -257,20 +256,20 @@ bd_ans_os_Watchdog(device_t *dev, BOARD_PRIVATE_STRUCT *bps)
      * we need to send an indication.
      */
     /* Compare current status against previous one: if equal, just return */
-    if(BD_ANS_BCMP(&piANSdata->prev_status, &current_status,
-        sizeof(IANS_BD_PARAM_STATUS)) == BD_ANS_TRUE) {
+    if (BD_ANS_BCMP((UCHAR *)&piANSdata->prev_status, (UCHAR *)&current_status,
+                    sizeof(IANS_BD_PARAM_STATUS)) == BD_ANS_TRUE) {
 
         return;
     }
     
     /* if we are here, we need to send a status change notification */
-    
     /* as far as I can tell, since it hasn't been defined yet,
      * the thing to do here is to call netdev_state_change(dev).
      * this is a synchronous call to a registered chain of who knows
      * how many protocols, so it seems like this wouldn't be a very good idea...
      */
-    BD_ANS_BCOPY(&piANSdata->prev_status, &current_status, sizeof(IANS_BD_PARAM_STATUS));
+    BD_ANS_BCOPY((UCHAR *)&piANSdata->prev_status, (UCHAR *)&current_status,
+                 sizeof(IANS_BD_PARAM_STATUS));
 
     DEBUGLOG("bd_ans_os_Watchdog: sending notification\n");
     if (ans_notify)
@@ -461,10 +460,6 @@ bd_ans_os_AttributeFill(iANS_Attribute_ID attr_id,
 void 
 bd_ans_os_ReserveSpaceForANS(struct sk_buff *skb)
 {
-  
-  
-  
-  
     skb_reserve(skb, BD_ANS_INFO_SIZE);
 }
        
