@@ -54,14 +54,18 @@
 
 #include <linux/sockios.h> /* for SIOCDEVPRIVATE */
 
-#define UINT16 unsigned short
-#define UINT32 unsigned long
-#define UCHAR  unsigned char
+#define UINT16 __u16
+#define UINT32 __u32
+#define UCHAR  __u8
 
 
 /* Make sure all communications parties use the same packing mode
  * for the shared structures. */
+#ifdef __ia64__
+#pragma pack(8)
+#else
 #pragma pack(4)
+#endif /*  __ia64__ */ 
 
 #ifdef _IANS_MAIN_MODULE_C_
 #define IntOrExt
@@ -502,7 +506,7 @@ typedef struct _IANS_BD_PARAM_IVLAN_TABLE
 
     UINT32        VLanIDNum;       /* Number of VLan IDs defined in 
                                       this table */
-    UINT16        VLanIDTable[1];  /* Beginning of ID list. 
+    UINT16        *VLanIDTable;  /* Beginning of ID list. 
                                     * iANS will allocate enough space 
                                     * for the whole table, and it will 
                                     * start from this field - we don't 
@@ -546,7 +550,7 @@ typedef struct _IANS_ATTR_HEADER
 #if defined(__i386__)
 #define CelingAlignPtr(p)       ( p )
 #else
-#error TBD 
+#define CelingAlignPtr(p)       ( p )
 #endif
 
 /* The attribute header is kept at the beginning of the allocated buffer */
