@@ -102,14 +102,10 @@ static int e100_read_align_enable = 0;
 
 /* extern variables */
 extern int e100_enhanced_tx_enable;
-extern int e100_flow_control_enable;
 extern int e100_speed_duplex[MAX_NIC];
+extern int flow_control[MAX_NIC];
 extern int XsumRX[MAX_NIC];
 
-
-static void e100_config_vlan_drop(bd_config_t *bdp, boolean_t enable);
-static void e100_config_long_rx(bd_config_t *bdp, boolean_t enable);
-
 /*
  * Procedure:   e100_config_init
  *
@@ -208,7 +204,7 @@ void e100_config_init(bd_config_t *bdp)
      */
     if (bddp->flags & IS_BACHELOR) {  /* This is 558 and up - enable extended counters */
         
-        if (bddp->rev_id >= D101MA_REV_ID) {   /* this is 559 and up - enable TCO counters */
+        if (bdp->rev_id >= D101MA_REV_ID) {   /* this is 559 and up - enable TCO counters */
             bdp->config[6] |= CB_CFIG_TCO_STAT;
             bdp->config[6] |= CB_CFIG_EXT_STAT_DIS;
             bddp->stat_mode = E100_TCO_STATS;
@@ -237,7 +233,7 @@ void e100_config_init(bd_config_t *bdp)
     
     /* Setup for MII or 503 operation.  The CRS+CDT bit should only be set */
     /* when operating in 503 mode. */
-    if (bddp->phy_addr == 32) {
+    if (bdp->phy_addr == 32) {
         bdp->config[8] = (CB_557_CFIG_DEFAULT_PARM8 & (~CB_CFIG_503_MII));
         bdp->config[15] = (CB_557_CFIG_DEFAULT_PARM15 | CB_CFIG_CRS_OR_CDT);
     } else {
@@ -247,7 +243,7 @@ void e100_config_init(bd_config_t *bdp)
     
     /* Change for 82558 enhancement */
     /* enable flow control only if not 557 */
-    if ((bddp->flags & IS_BACHELOR) && (e100_flow_control_enable)) {
+    if ((bddp->flags & IS_BACHELOR) && (flow_control[bdp->bd_number] == TRUE)) {
         bdp->config[16] = DFLT_FC_DELAY_LSB;
         bdp->config[17] = DFLT_FC_DELAY_MSB;
         /* Removed CB_CFIG_TX_FC_EN frm line below. This bit has to be 0 to 
@@ -257,25 +253,23 @@ void e100_config_init(bd_config_t *bdp)
     } else {
         bdp->config[16] = CB_557_CFIG_DEFAULT_PARM16;
         bdp->config[17] = CB_557_CFIG_DEFAULT_PARM17;
-        /* Bit 2 has to be 'OR'd to disable flow control. */
         bdp->config[19] = CB_557_CFIG_DEFAULT_PARM19 | CB_CFIG_TX_FC_DIS;
     }
     
     e100_config_force_dplx(bdp);
-    e100_config_promisc(bdp);
-    e100_config_brdcst_dsbl(bdp);
-    e100_config_mulcst_enbl(bdp);
+    e100_config_promisc(bdp, B_FALSE);
+    e100_config_mulcast_enbl(bdp, B_FALSE);
     
     /* Enable checksum offloading if we are on a supported adapter. */
-    if ((bddp->rev_id >= D101MA_REV_ID) && (bddp->rev_id < D102_REV_ID) &&
-        (XsumRX[bddp->bd_number] == TRUE) && (bddp->dev_id != 0x1209)) {
+    if ((bdp->rev_id >= D101MA_REV_ID) && (bdp->rev_id < D102_REV_ID) &&
+        (XsumRX[bdp->bd_number] == TRUE) && (bdp->ppci_dev->device != 0x1209)) {
         
-#ifndef __ia64__
-        bddp->checksum_offload_enabled = 1;
+#ifdef __i386__
+        bdp->checksum_offload_enabled = 1;
         bdp->config[9] |= 1;
-#endif /* __ia64__ */
+#endif /* __i386__ */
 
-    } else if (bddp->rev_id >= D102_REV_ID) {
+    } else if (bdp->rev_id >= D102_REV_ID) {
         /* The D102 chip allows for 32 config bytes.  This value is
            supposed to be in Byte 0.  Just add the extra bytes to
            what was already setup in the block. */
@@ -291,22 +285,46 @@ void e100_config_init(bd_config_t *bdp)
         bdp->config[22] = CB_CFIG_RECEIVE_GAMLA_MODE;
         
         /* set the flag if checksum offloading was enabled */
-        if (XsumRX[bddp->bd_number] == TRUE) {
-            bddp->checksum_offload_enabled = 1;
+        if (XsumRX[bdp->bd_number] == TRUE) {
+            bdp->checksum_offload_enabled = 1;
         }
     }
-    /*
-      #ifdef IANS
-      if (ANS_PRIVATE_DATA_FIELD(bdp)->iANS_status == IANS_COMMUNICATION_UP) {
-      
-      #ifdef IANS_BASE_VLAN_TAGGING
-      if (ANS_PRIVATE_DATA_FIELD(bdp)->vlan_mode == IANS_VLAN_MODE_ON) {
-      bd_ans_hw_ConfigEnableTagging(bdp->config, bddp->rev_id);
-      }
-      #endif
-      }
-      #endif
-    */
+}
+
+/*
+ * Procedure:   e100_force_config
+ *
+ * Description: This routine will force a configure command to the 82557.
+ *              This command will be executed in polled mode as interrupts
+ *              are _disabled_ at this time.  The configuration parameters
+ *              that are user configurable will have been set in "e100.c".
+ *
+ * Arguments:
+ *      bdp    - Ptr to this card's e100_bdconfig structure
+ *
+ * Returns:
+ *      B_TRUE - If the configure command was successfully issued and completed
+ *      B_FALSE - If the configure command failed to complete properly
+ */
+boolean_t
+e100_force_config(bd_config_t *bdp)
+{
+    unsigned long   lock_flag_conf;
+    
+    spin_lock_irqsave(&(bdp->config_lock), lock_flag_conf);
+    
+    bdp->config[0] = CB_CFIG_BYTE_COUNT;
+    if (bdp->rev_id >= D102_REV_ID) {
+        /* The D102 chip allows for 32 config bytes.  This value is
+           supposed to be in Byte 0.  Just add the extra bytes to
+           what was already setup in the block. */
+        bdp->config[0] += CB_CFIG_D102_BYTE_COUNT;
+    }
+
+    spin_unlock_irqrestore(&(bdp->config_lock), lock_flag_conf);
+    // although we call config outside the lock, there is no
+    // race condition because config byte count has maximum value
+    return e100_config(bdp);
 }
 
 /*
@@ -329,15 +347,32 @@ e100_config(bd_config_t *bdp)
 {
         bdd_t          *bddp = bdp->bddp;   /* stores all adapter specific info */
         pcb_header_t    pntcb_hdr;
-        int             e100_retry, timeout;
+        int             timeout;
         unsigned long   lock_flag_bd;
-        unsigned long   lock_flag_tx;
         unsigned long   lock_flag_conf;
-    
-        spin_lock_irqsave(&bddp->bd_tx_lock, lock_flag_tx);
-        spin_lock_irqsave(&bddp->bd_lock, lock_flag_bd);
-        spin_lock_irqsave(&bddp->config_lock, lock_flag_conf);
-   
+        boolean_t	res;
+
+        spin_lock_bh(&bdp->bd_tx_lock);
+
+        timeout = 1000*500;
+
+        if (bdp->bddp->last_tcbp) {
+                E100_WAIT_FOR_CONDITION(timeout,
+                                        (bdp->bddp->last_tcbp->tcb_hdr.cb_status & 
+                                         __constant_cpu_to_le16(CB_STATUS_COMPLETE)));
+        }        
+        E100_WAIT_FOR_CONDITION(timeout,
+                                ((readw(&bddp->scbp->scb_status) & SCB_CUS_MASK)
+                                 != SCB_CUS_ACTIVE));
+        if(timeout <= 0) {
+                spin_unlock_bh(&bdp->bd_tx_lock);
+                e100_tx_notify_start(bdp);
+                printk(KERN_WARNING "%s: Config failed\n",bdp->device->name);
+                return B_FALSE;  
+        }
+        spin_lock_irqsave(&bdp->bd_lock, lock_flag_bd);
+        spin_lock_irqsave(&bdp->config_lock, lock_flag_conf);
+        
         pntcb_hdr = (pcb_header_t) bddp->pntcb;   /* get hdr of non tcb cmd */
 
         /* Setup the non-transmit command block header for the configure command. */
@@ -353,60 +388,33 @@ e100_config(bd_config_t *bdp)
         /* Wait for the SCB command word to clear before we set the * general
          * pointer */
         if (e100_wait_scb(bdp) != B_TRUE) {
-                spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
-                spin_unlock_irqrestore(&bddp->bd_lock, lock_flag_bd);
-                spin_unlock_irqrestore(&bddp->bd_tx_lock, lock_flag_tx);
+                spin_unlock_irqrestore(&(bdp->config_lock), lock_flag_conf);
+                spin_unlock_irqrestore(&(bdp->bd_lock), lock_flag_bd);
+                spin_unlock_bh(&bdp->bd_tx_lock);
+                e100_tx_notify_start(bdp);
                 return (B_FALSE);
         }
 
-        if (bdp->bddp->last_tcbp) {
-                timeout = 1000*500;
-                E100_WAIT_FOR_CONDITION(timeout,
-                                        (bdp->bddp->last_tcbp->tcb_hdr.cb_status & 
-                                         __constant_cpu_to_le16(CB_STATUS_COMPLETE)));
-                if(timeout <= 0) {
-                        spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
-                        spin_unlock_irqrestore(&bddp->bd_lock, lock_flag_bd);
-                        spin_unlock_irqrestore(&bddp->bd_tx_lock, lock_flag_tx);
-                        printk(KERN_WARNING "Config failed\n");
-                        return B_FALSE;  
-                }
-        }       
-
-        e100_retry = E100_CMD_WAIT;
-        while (((readw(&bddp->scbp->scb_status) & SCB_CUS_MASK) == SCB_CUS_ACTIVE)
-               && (e100_retry)) {
-                mdelay(20);
-                e100_retry--;
-        }
-        if(!e100_retry){
-                printk("%s config: timeout waiting for CU\n",
-                       bdp->device->name);
-                spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
-                spin_unlock_irqrestore(&bddp->bd_lock, lock_flag_bd);
-                spin_unlock_irqrestore(&bddp->bd_tx_lock, lock_flag_tx);
-                return B_FALSE;
-        }                
-    
         bddp->next_cu_cmd = START_WAIT;
 
         /* write the config buffer in the scb gen pointer */
         writel(bddp->nontx_paddr, &(bddp->scbp->scb_gen_ptr));
 
         /* Submit the configure command to the chip, and wait for it to complete. */
-        if (!e100_exec_poll_cmd(bdp)) {
-                spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
-                spin_unlock_irqrestore(&bddp->bd_lock, lock_flag_bd);
-                spin_unlock_irqrestore(&bddp->bd_tx_lock, lock_flag_tx);
-                return B_FALSE;
-        
+        e100_exec_non_cu_cmd(bdp);
+        spin_unlock_irqrestore(&bdp->config_lock, lock_flag_conf);
+        spin_unlock_irqrestore(&bdp->bd_lock, lock_flag_bd);
+
+        if (!e100_poll_cmd(bdp)) {
+                res= B_FALSE;
         } else {
-                bdp->config[0] = CB_CFIG_MIN_PARAMS;  /* reset number of bytes to config next time */
-                spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
-                spin_unlock_irqrestore(&bddp->bd_lock, lock_flag_bd);
-                spin_unlock_irqrestore(&bddp->bd_tx_lock, lock_flag_tx);
-                return B_TRUE;
+                bdp->config[0] = CB_CFIG_MIN_PARAMS; 
+                /* reset number of bytes to config next time */
+                res=B_TRUE;
         }
+        spin_unlock_bh(&bdp->bd_tx_lock);
+        e100_tx_notify_start(bdp);        
+        return res;
 }
 
 /*
@@ -418,19 +426,19 @@ e100_config(bd_config_t *bdp)
  *
  * Arguments:
  *      bdp    - Ptr to this card's e100_bdconfig structure
+ *      enable - should we enable this option or not
  *
  * Returns:
  */
 void
-e100_config_promisc(bd_config_t *bdp)
+e100_config_promisc(bd_config_t *bdp, boolean_t enable)
 {
-    bdd_t          *bddp = bdp->bddp;   /* stores all adapter specific info */
     unsigned long   lock_flag_conf;
     
-    spin_lock_irqsave(&bddp->config_lock, lock_flag_conf);
+    spin_lock_irqsave(&(bdp->config_lock), lock_flag_conf);
     
     /* if in promiscuous mode, save bad frames */
-    if (bddp->promisc) {
+    if (enable == B_TRUE) {
         
         if (!(bdp->config[6] & CB_CFIG_SAVE_BAD_FRAMES)) {
             bdp->config[6] |= CB_CFIG_SAVE_BAD_FRAMES;
@@ -465,48 +473,12 @@ e100_config_promisc(bd_config_t *bdp)
         }
     }
     
-    spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
+    spin_unlock_irqrestore(&(bdp->config_lock), lock_flag_conf);
 }
 
-/*
- * Procedure:   e100_config_brdcst_dsbl
- *
- * Description: This routine will enable or disable broadcast
- *              in the adapter's congif block, as indicated by the
- *              adapter's e100_bdconfig structure.
- *
- * Arguments:
- *      bdp    - Ptr to this card's e100_bdconfig structure
- *
- * Returns:
- */
-void
-e100_config_brdcst_dsbl(bd_config_t *bdp)
-{
-    bdd_t          *bddp = bdp->bddp;   /* stores all adapter specific info */
-    unsigned long   lock_flag_conf;
-    
-    spin_lock_irqsave(&bddp->config_lock, lock_flag_conf);
-    
-    /* disable broadcast if so desired */
-    if (bddp->brdcst_dsbl) {
-        if (!(bdp->config[15] & CB_CFIG_BROADCAST_DIS)) {
-            bdp->config[15] |= CB_CFIG_BROADCAST_DIS;
-            E100_CONFIG(bdp, 15);
-        }            
-        
-    } else {
-        if (bdp->config[15] & CB_CFIG_BROADCAST_DIS) {
-            bdp->config[15] &= ~CB_CFIG_BROADCAST_DIS;
-            E100_CONFIG(bdp, 15);
-        }
-    }
-    
-    spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
-}
 
 /*
- * Procedure:   e100_config_mulcst_enbl
+ * Procedure:   e100_config_mulcast_enbl
  *
  * Description: This routine will enable or disable multicast packets
  *              in the adapter's congif block, as indicated by the
@@ -514,19 +486,19 @@ e100_config_brdcst_dsbl(bd_config_t *bdp)
  *
  * Arguments:
  *      bdp    - Ptr to this card's e100_bdconfig structure
+ *      enable - should we enable this option or not
  *
  * Returns:
  */
 void
-e100_config_mulcst_enbl(bd_config_t *bdp)
+e100_config_mulcast_enbl(bd_config_t *bdp, boolean_t enable)
 {
-    bdd_t          *bddp = bdp->bddp;   /* stores all adapter specific info */
     unsigned long   lock_flag_conf;
     
-    spin_lock_irqsave(&bddp->config_lock, lock_flag_conf);
+    spin_lock_irqsave(&(bdp->config_lock), lock_flag_conf);
     
     /* this flag is used to enable receiving all multicast packet */
-    if (bddp->mulcst_enbl) {
+    if (enable == B_TRUE) {
         if (!(bdp->config[21] & CB_CFIG_MULTICAST_ALL)) {
             bdp->config[21] |= CB_CFIG_MULTICAST_ALL;
             E100_CONFIG(bdp, 21);
@@ -539,7 +511,7 @@ e100_config_mulcst_enbl(bd_config_t *bdp)
         }
     }
     
-    spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
+    spin_unlock_irqrestore(&(bdp->config_lock), lock_flag_conf);
 }
 
 /*
@@ -559,17 +531,21 @@ e100_config_ifs(bd_config_t *bdp)
 {
     bdd_t          *bddp = bdp->bddp;   /* stores all adapter specific info */
     unsigned long   lock_flag_conf;
+    uint8_t         value = 0;
     
-    spin_lock_irqsave(&bddp->config_lock, lock_flag_conf);
+    spin_lock_irqsave(&(bdp->config_lock), lock_flag_conf);
     
     /* IFS value is only needed to be specified at half-duplex mode */
     if (bddp->cur_dplx_mode == HALF_DUPLEX) {
-        bdp->config[2] = (uint8_t) bdp->ifs_value;
-    } else {
-        bdp->config[2] = 0;
+        value = (uint8_t) bdp->ifs_value;
     }
     
-    spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
+    if (bdp->config[2] != value) {
+        bdp->config[2] = value;
+        E100_CONFIG(bdp, 2);
+    }
+    
+    spin_unlock_irqrestore(&(bdp->config_lock), lock_flag_conf);
 }
 
 /*
@@ -590,7 +566,7 @@ e100_config_force_dplx(bd_config_t *bdp)
     bdd_t          *bddp = bdp->bddp;   /* stores all adapter specific info */
     unsigned long   lock_flag_conf;
     
-    spin_lock_irqsave(&bddp->config_lock, lock_flag_conf);
+    spin_lock_irqsave(&(bdp->config_lock), lock_flag_conf);
     
     /* We must force full duplex on if we are using PHY 0, and we are */
     /* supposed to run in FDX mode.  We do this because the e100 has only */
@@ -600,12 +576,12 @@ e100_config_force_dplx(bd_config_t *bdp)
      * not, because the cur_dplx_mode was not being set to 2 by SetupPhy. *
      * This is how the condition was, initially. * This has been changed so
      * that the MAC gets forced to full duplex * simply if the user has
-     * forced full duplex. * * if (( bddp->phy_addr == 0 ) && (
+     * forced full duplex. * * if (( bdp->phy_addr == 0 ) && (
      * bddp->cur_dplx_mode == 2 )) */
     /* The rest of the fix is in the PhyDetect code.          */
     if ((e100_speed_duplex[bdp->bd_number] == 2) ||
         (e100_speed_duplex[bdp->bd_number] == 4) ||
-        ((bddp->phy_addr == 32) && (bddp->cur_dplx_mode == FULL_DUPLEX))) {
+        ((bdp->phy_addr == 32) && (bddp->cur_dplx_mode == FULL_DUPLEX))) {
         if (!(bdp->config[19] & CB_CFIG_FORCE_FDX)) {
             bdp->config[19] |= CB_CFIG_FORCE_FDX;
             E100_CONFIG(bdp, 19);
@@ -618,9 +594,11 @@ e100_config_force_dplx(bd_config_t *bdp)
         }
     }
     
-    spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
+    spin_unlock_irqrestore(&(bdp->config_lock), lock_flag_conf);
 }
 
+#ifdef IANS_BASE_VLAN_TAGGING
+
 /*
  * Procedure:   e100_config_long_rx
  *
@@ -691,16 +669,17 @@ e100_config_vlan_drop(bd_config_t *bdp, boolean_t enable)
 void
 e100_config_enable_tagging(bd_config_t *bdp, boolean_t enable)
 {
-    bdd_t          *bddp = bdp->bddp;   /* stores all adapter specific info */
     unsigned long   lock_flag_conf;
     
-    spin_lock_irqsave(&bddp->config_lock, lock_flag_conf);
+    spin_lock_irqsave(&(bdp->config_lock), lock_flag_conf);
     
-    if (bddp->rev_id >= D101B0_REV_ID)
+    if (bdp->rev_id >= D101B0_REV_ID)
         e100_config_long_rx(bdp, enable);
     
-    if (bddp->rev_id >= D102_REV_ID)
+    if (bdp->rev_id >= D102_REV_ID)
         e100_config_vlan_drop(bdp, enable);
     
-    spin_unlock_irqrestore(&bddp->config_lock, lock_flag_conf);
+    spin_unlock_irqrestore(&(bdp->config_lock), lock_flag_conf);
 }
+#endif /* IANS_BASE_VLAN_TAGGING */
+
