@@ -57,40 +57,6 @@ Abstract:
 //****************************************************************************************
 
 
-//-----------------------------------------------------------------------------
-// Procedure: ValidateEEprom
-//
-// Description: Determine whether the eeprom is accurate
-//
-// Arguments:
-//          Ptr to this card's adapter data structure 
-// 
-// Returns: TRUE or FALSE whether the eeprom is clean
-//-----------------------------------------------------------------------------
-
-_STATUS 
-ValidateEEprom (
-	IN PD100_ADAPTER adapter
-)
-{
-    USHORT  idx, checksum = 0;
-	_STATUS status = _STATUS_SUCCESS;
-
-    TRACE ((LVL_ENTRY, "ValidateEEprom\n"));
-
-    // eeprom size is initialized to zero
-    if (!adapter->EEpromSize)
-        adapter->EEpromSize = GetEEpromSize (adapter);
-
-    for (idx = 0; idx < adapter->EEpromSize; idx++)
-        checksum += ReadEEprom (adapter, idx);
-
-    if (checksum != le16_to_cpu(EEPROM_CHECKSUM))
-		status = _STATUS_FAILURE;
-
-	return status;
-}
-
 
 //----------------------------------------------------------------------------------------
 // Procedure:   GetEEpromSize
@@ -106,79 +72,65 @@ ValidateEEprom (
 // Returns:
 //      Size of the eeprom, or zero if an error occured
 //----------------------------------------------------------------------------------------
+/**/
 
-USHORT
-GetEEpromSize (
-    IN PD100_ADAPTER adapter
-)
+
+__u16 GetEEpromSize(bd_config_t *adapter)
 {
-    USHORT  x, size = 1;        // must be one to accumulate a product
-
-    TRACE ((LVL_ENTRY, "GetEEpromSize\n"));
+    __u16 x, size = 1;        // must be one to accumulate a product
 
     // if we've already stored this data, read from memory
-    if (adapter->EepromData.Size)
-    {
-        TRACE((LVL_EEPROM, "GetEEpromSize::Using buffered value.\n"));
+    if (adapter->EepromData.Size) {
         size = adapter->EepromData.Size;
-    }
-    // otherwise, read from the eeprom
-    else
-    {
+
+    } else { // otherwise, read from the eeprom
         // Set EEPROM semaphore.
-        if (adapter->AiRevID >= D102_A_STEP)
-        {
-                WAIT_FOR_CONDITION (adapter, EEPROM_SEMAPHORE_TIMEOUT,
-                EepromSetSemaphore (adapter));
+        if (adapter->rev_id >= D102_REV_ID) {
+            WAIT_FOR_CONDITION (adapter, EEPROM_SEMAPHORE_TIMEOUT,
+                                EepromSetSemaphore (adapter));
         }
 
         // enable the eeprom by setting EECS.
-        x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
+        x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
         x &= ~(EEDI | EEDO | EESK);
         x |= EECS;
-        Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
+        writew(x ,&CSR_EEPROM_CONTROL_FIELD(adapter));
 
         // write the read opcode
         ShiftOutBits (adapter, EEPROM_READ_OPCODE, 3);
 
         // experiment to discover the size of the eeprom.  request register zero
         // and wait for the eeprom to tell us it has accepted the entire address.
-        x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
-        do
-        {
+        x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
+        do {
             size *= 2;          // each bit of address doubles eeprom size
             x |= EEDO;          // set bit to detect "dummy zero"
             x &= ~EEDI;         // address consists of all zeros
 
-            Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
-            StallExecutionMicro (STALL_TIME);
+            writew(x ,&CSR_EEPROM_CONTROL_FIELD(adapter));
+            udelay (STALL_TIME);
             RaiseClock (adapter, &x);
             LowerClock (adapter, &x);
 
             // check for "dummy zero"
-            x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
-            if (size > EEPROM_MAX_WORD_SIZE)
-            {
+            x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
+            if (size > EEPROM_MAX_WORD_SIZE) {
                 size = 0;
                 break;
             }
-        }
-        while (x & EEDO);
+        } while (x & EEDO);
 
         // read in the value requested
         (void) ShiftInBits (adapter);
         EEpromCleanup (adapter);
 
         // Clear EEPROM Semaphore.
-        if (adapter->AiRevID >= D102_A_STEP)
-        {
+        if (adapter->rev_id >= D102_REV_ID) {
             EepromResetSemaphore (adapter);
         }
 
     }
 
-    TRACE ((LVL_EEPROM, "EEprom size is: %d\n", size));
-    ASSERT (size > 0);
     return size;
 }
 
@@ -196,13 +148,8 @@ GetEEpromSize (
 //      bits in an address for that size eeprom
 //----------------------------------------------------------------------------------------
 
-USHORT
-EEpromAddressSize (
-    IN USHORT size
-)
+__u16 EEpromAddressSize(__u16 size)
 {
-    TRACE ((LVL_ENTRY, "EEpromAddressSize\n"));
-    ASSERT (size == 64 || size == 128 || size == 256);
     switch (size)
     {
         case 64:    return 6;
@@ -231,54 +178,43 @@ EEpromAddressSize (
 //      Contents of EEPROM word (reg).
 //----------------------------------------------------------------------------------------
 
-USHORT
-ReadEEprom (
-    IN PD100_ADAPTER adapter,
-    IN USHORT reg
-)
+__u16 ReadEEprom(bd_config_t *adapter, __u16 reg)
 {
-    USHORT      x, data, bits;
-
-    TRACE ((LVL_ENTRY, "ReadEEprom\n"));
-    {
-        // Set EEPROM semaphore.
-        if (adapter->AiRevID >= D102_A_STEP)
-        {
-            WAIT_FOR_CONDITION (adapter, EEPROM_SEMAPHORE_TIMEOUT, EepromSetSemaphore (adapter))
-        }
-
-        // eeprom size is initialized to zero
-        if (!adapter->EEpromSize)
-            adapter->EEpromSize = GetEEpromSize (adapter);
-
-        bits = EEpromAddressSize (adapter->EEpromSize);
-
-        // select EEPROM, reset bits, set EECS
-        x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
-
-        x &= ~(EEDI | EEDO | EESK);
-        x |= EECS;
-        Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
-
-        // write the read opcode and register number in that order
-        // The opcode is 3bits in length, reg is 'bits' bits long
-        ShiftOutBits (adapter, EEPROM_READ_OPCODE, 3);
-        ShiftOutBits (adapter, reg, bits);
-
-        // Now read the data (16 bits) in from the selected EEPROM word
-        data = ShiftInBits (adapter);
-
-        EEpromCleanup (adapter);
-
-        // Clear EEPROM Semaphore.
-        if (adapter->AiRevID >= D102_A_STEP)
-        {
-            EepromResetSemaphore (adapter);
-        }
+    __u16      x, data, bits;
 
+    // Set EEPROM semaphore.
+    if (adapter->rev_id >= D102_REV_ID) {
+        WAIT_FOR_CONDITION (adapter, EEPROM_SEMAPHORE_TIMEOUT, EepromSetSemaphore (adapter));
+    }
+    
+    // eeprom size is initialized to zero
+    if (!adapter->EEpromSize)
+        adapter->EEpromSize = GetEEpromSize (adapter);
+    
+    bits = EEpromAddressSize (adapter->EEpromSize);
+    
+    // select EEPROM, reset bits, set EECS
+    x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
+    
+    x &= ~(EEDI | EEDO | EESK);
+    x |= EECS;
+    writew(x, &CSR_EEPROM_CONTROL_FIELD(adapter));
+    
+    // write the read opcode and register number in that order
+    // The opcode is 3bits in length, reg is 'bits' bits long
+    ShiftOutBits (adapter, EEPROM_READ_OPCODE, 3);
+    ShiftOutBits (adapter, reg, bits);
+    
+    // Now read the data (16 bits) in from the selected EEPROM word
+    data = ShiftInBits (adapter);
+    
+    EEpromCleanup (adapter);
+    
+    // Clear EEPROM Semaphore.
+    if (adapter->rev_id >= D102_REV_ID) {
+        EepromResetSemaphore (adapter);
     }
     
-    TRACE ((LVL_EEPROM, "ReadEEprom returns: 0x%X Location: %d\n", data, reg));
     return data;
 }
 
@@ -295,35 +231,28 @@ ReadEEprom (
 // Returns: (none)
 //----------------------------------------------------------------------------------------
 
-VOID
-ShiftOutBits (
-    IN PD100_ADAPTER adapter,
-    IN USHORT data,
-    IN USHORT count
-)
+void ShiftOutBits(bd_config_t *adapter, __u16 data, __u16 count)
 {
-    USHORT  x, mask;
-    TRACE ((LVL_ENTRY, "ShiftOutBits\n"));
+    __u16 x, mask;
 
     mask = 1 << (count - 1);
-    x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
+    x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
     x &= ~(EEDO | EEDI);
 
-    do
-    {
+    do {
         x &= ~EEDI;
         if (data & mask)
             x |= EEDI;
 
-        Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
-        StallExecutionMicro (STALL_TIME);
+        writew(x, &CSR_EEPROM_CONTROL_FIELD(adapter));
+        udelay (STALL_TIME);
         RaiseClock (adapter, &x);
         LowerClock (adapter, &x);
         mask = mask >> 1;
     } while (mask);
 
     x &= ~EEDI;
-    Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
+    writew(x, &CSR_EEPROM_CONTROL_FIELD(adapter));
 }
 
 
@@ -338,16 +267,11 @@ ShiftOutBits (
 // Returns: (none)
 //----------------------------------------------------------------------------------------
 
-VOID
-RaiseClock (
-    IN PD100_ADAPTER adapter,
-    IN OUT PUSHORT x
-)
+void RaiseClock(bd_config_t *adapter, __u16 * x)
 {
-    TRACE ((LVL_ENTRY, "RaiseClock\n"));
     *x = *x | EESK;
-    Csr_Write16 (adapter, CSR_EEPROM_CONTROL, *x);
-    StallExecutionMicro (STALL_TIME);
+    writew(*x, &CSR_EEPROM_CONTROL_FIELD(adapter));
+    udelay (STALL_TIME);
 }
 
 
@@ -362,16 +286,11 @@ RaiseClock (
 // Returns: (none)
 //----------------------------------------------------------------------------------------
 
-VOID
-LowerClock (
-    IN PD100_ADAPTER adapter,
-    IN OUT PUSHORT x
-)
+void LowerClock(bd_config_t *adapter, __u16 *x)
 {
-    TRACE ((LVL_ENTRY, "LowerClock\n"));
     *x = *x & ~EESK;
-    Csr_Write16 (adapter, CSR_EEPROM_CONTROL, *x);
-    StallExecutionMicro (STALL_TIME);
+    writew(*x, &CSR_EEPROM_CONTROL_FIELD(adapter));
+    udelay (STALL_TIME);
 }
 
 
@@ -386,24 +305,19 @@ LowerClock (
 //      The contents of that particular EEPROM word
 //----------------------------------------------------------------------------------------
 
-USHORT
-ShiftInBits (
-    IN PD100_ADAPTER adapter
-)
+__u16 ShiftInBits(bd_config_t *adapter)
 {
-    USHORT  x, d, i;
-    TRACE ((LVL_ENTRY, "ShiftInBits\n"));
+    __u16 x, d, i;
 
-    x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
+    x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
     x &= ~(EEDO | EEDI);
     d = 0;
 
-    for (i = 0; i < 16; i++)
-    {
+    for (i = 0; i < 16; i++) {
         d <<= 1;
         RaiseClock (adapter, &x);
 
-        x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
+        x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
 
         x &= ~EEDI;
         if (x & EEDO)
@@ -426,17 +340,13 @@ ShiftInBits (
 // Returns: (none)
 //----------------------------------------------------------------------------------------
 
-VOID
-EEpromCleanup (
-    IN PD100_ADAPTER adapter
-)
+void EEpromCleanup(bd_config_t *adapter)
 {
-    USHORT  x;
-    TRACE ((LVL_ENTRY, "EEpromCleanup\n"));
-    x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
+    __u16 x;
+    x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
 
     x &= ~(EECS | EEDI);
-    Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
+    writew(x, &CSR_EEPROM_CONTROL_FIELD(adapter));
 
     RaiseClock (adapter, &x);
     LowerClock (adapter, &x);
@@ -453,32 +363,22 @@ EEpromCleanup (
 // Returns: true/false  succeed/fail
 //----------------------------------------------------------------------------------------
 
-BOOLEAN
-ReadEEpromNodeAddress (
-    IN PD100_ADAPTER adapter,
-    OUT PUCHAR buffer,
-    IN UINT size
-)
+boolean_t ReadEEpromNodeAddress(bd_config_t *adapter, __u8 *buffer, unsigned int size)
 {
-    USHORT  value;
-    UCHAR   data [ETH_LENGTH_OF_ADDRESS];
-    USHORT  idx;
-    TRACE ((LVL_ENTRY, "ReadEEpromNodeAddress\n"));
+    __u16 value;
+    __u8  data [ETHERNET_ADDRESS_LENGTH];
+    __u16 idx;
 
-    if (size < ETH_LENGTH_OF_ADDRESS)
+    if (size < ETHERNET_ADDRESS_LENGTH)
         return FALSE;
 
-    ASSERT (sizeof (USHORT) == 2);
-
-    for (idx = 0; idx < ETH_LENGTH_OF_ADDRESS / 2; idx++)
-    {
-        value = ReadEEprom (adapter, (USHORT) (EEPROM_NODE_ADDRESS_BYTE_0 + idx));
-        data [idx*2]     = (UCHAR) value;
-        data [idx*2 + 1] = (UCHAR) (value >> 8);
+    for (idx = 0; idx < ETHERNET_ADDRESS_LENGTH / 2; idx++) {
+        value = ReadEEprom (adapter, (__u16) (EEPROM_NODE_ADDRESS_BYTE_0 + idx));
+        data [idx*2]     = (__u8) value;
+        data [idx*2 + 1] = (__u8) (value >> 8);
     }
-    ETH_COPY_NETWORK_ADDRESS (buffer, data);
-    TRACE ((LVL_EEPROM, "ReadEEpromNodeAddress: %02X-%02X-%02X-%02X-%02X-%02X\n",
-        data [0], data [1], data [2], data [3], data [4], data [5]));
+    memcpy(buffer, data, 6);
+
     return TRUE;
 }
 
@@ -501,13 +401,9 @@ ReadEEpromNodeAddress (
 // Returns: (none)
 //----------------------------------------------------------------------------------------
 
-VOID
-UpdateChecksum (
-    IN PD100_ADAPTER adapter
-)
+void UpdateChecksum(bd_config_t *adapter)
 {
-    USHORT  idx, xsumIndex, checksum = 0;
-    TRACE ((LVL_ENTRY, "UpdateChecksum\n"));
+    __u16 idx, xsumIndex, checksum = 0;
 
     // eeprom size is initialized to zero
     if (!adapter->EEpromSize)
@@ -538,15 +434,9 @@ UpdateChecksum (
  *
  * Returns: none
  *****************************************************************************/
-VOID
-QuickUpdateChecksum (
-    IN PD100_ADAPTER adapter,
-    IN USHORT reg,
-    IN USHORT oldData,
-    IN USHORT newData)
+void QuickUpdateChecksum(bd_config_t *adapter, __u16 reg, __u16 oldData, __u16 newData)
 {
-    USHORT  xsumIndex, curData, curXsum;
-    TRACE ((LVL_ENTRY, "QuickUpdateChecksum\n"));
+    __u16 xsumIndex, curData, curXsum;
 
     // eeprom size is initialized to zero
     if (!adapter->EEpromSize)
@@ -555,13 +445,13 @@ QuickUpdateChecksum (
     xsumIndex = adapter->EEpromSize - 1;
     curData = ReadEEprom(adapter, reg);
     curXsum = ReadEEprom(adapter, xsumIndex);
-    if (curData == newData)
-    {
+    if (curData == newData) {
         curXsum -= (newData - oldData);
         WriteEEprom (adapter, xsumIndex, curXsum);
-    }
-    else if (curData != oldData)      /* unexpected data */
+
+    } else if (curData != oldData) {     /* unexpected data */
         UpdateChecksum(adapter);      /* calculate xsum - use all values */
+    }
 }
 
 //----------------------------------------------------------------------------------------
@@ -580,22 +470,14 @@ QuickUpdateChecksum (
 // Returns: (none)
 //----------------------------------------------------------------------------------------
 
-VOID
-WriteEEprom (
-    IN PD100_ADAPTER adapter,
-    IN USHORT reg,
-    IN USHORT data
-)
+void WriteEEprom(bd_config_t *adapter, __u16 reg, __u16 data)
 {
-    USHORT  x;
-    USHORT  bits;
-
-    TRACE ((LVL_ENTRY, "WriteEEprom\n"));
+    __u16 x;
+    __u16 bits;
 
     // Set EEPROM semaphore.
-    if (adapter->AiRevID >= D102_A_STEP)
-    {
-        WAIT_FOR_CONDITION (adapter, EEPROM_SEMAPHORE_TIMEOUT, EepromSetSemaphore (adapter))
+    if (adapter->rev_id >= D102_REV_ID) {
+        WAIT_FOR_CONDITION (adapter, EEPROM_SEMAPHORE_TIMEOUT, EepromSetSemaphore (adapter));
     }
 
     // eeprom size is initialized to zero
@@ -605,18 +487,16 @@ WriteEEprom (
     bits = EEpromAddressSize (adapter->EEpromSize);
 
     /* select EEPROM, mask off ASIC and reset bits, set EECS */
-    x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
+    x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
     x &= ~(EEDI | EEDO | EESK);
-    Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
-    StallExecutionMicro(1);
+    writew(x, &CSR_EEPROM_CONTROL_FIELD(adapter));
+    udelay(1);
     x |= EECS;
-    Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
+    writew(x, &CSR_EEPROM_CONTROL_FIELD(adapter));
 
     ShiftOutBits (adapter, EEPROM_EWEN_OPCODE, 5);
-    ShiftOutBits (adapter, reg, (USHORT) (bits-2));
-    if (WaitEEpromCmdDone (adapter) == FALSE)
-    {
-        TRACE ((LVL_EEPROM, "D100: Failed EEPROM Erase/Write Enable"));
+    ShiftOutBits (adapter, reg, (__u16) (bits-2));
+    if (WaitEEpromCmdDone (adapter) == FALSE) {
         return;
     }
     
@@ -628,70 +508,29 @@ WriteEEprom (
 
     /* write the data to the selected EEPROM word */
     ShiftOutBits (adapter, data, 16);
-    if (WaitEEpromCmdDone (adapter) == FALSE)
-    {
-        TRACE ((LVL_EEPROM, "D100: Failed EEPROM Write"));
+    if (WaitEEpromCmdDone (adapter) == FALSE) {
         return;
     }
     
     ShiftOutBits (adapter, EEPROM_EWDS_OPCODE, 5);
-    ShiftOutBits (adapter, reg, (USHORT) (bits-2));
-    if (WaitEEpromCmdDone (adapter) == FALSE)
-    {
-        TRACE ((LVL_EEPROM, "D100: Failed EEPROM Erase/Write Disable"));
+    ShiftOutBits (adapter, reg, (__u16) (bits-2));
+    if (WaitEEpromCmdDone (adapter) == FALSE) {
         return;
     }
 
     EEpromCleanup (adapter);
 
     // Clear EEPROM Semaphore.
-    if (adapter->AiRevID >= D102_A_STEP)
-    {
+    if (adapter->rev_id >= D102_REV_ID) {
         EepromResetSemaphore (adapter);
     }
 
     // update the eeprom buffer so subsequent reads will be accurate
-    if (adapter->EepromData.Initialized)
-    {
-        TRACE((LVL_EEPROM,
-               "WriteEEprom::Updating buffered value. Data: %x Location: %d\n", data, reg));
+    if (adapter->EepromData.Initialized) {
         adapter->EepromData.Data[reg] = data;
     }
 }
 
-/******************************************************************************
- * Procedure:   WriteBlockEEprom
- *
- * Description: This routine writes a block of words to the specified EEPROM
- *       locations.
- *
- * Arguments:
- *      adapter - pointer to adapter
- *    startReg - starting EEPROM word that we are going to write to.
- *    dataLength - number of words that we are going to write
- *    pData - Data (words) that we are going to write to the EEPROM.
- *
- * Returns: none
- *****************************************************************************/
-VOID
-WriteBlockEEprom (
-    IN PD100_ADAPTER adapter,
-    IN USHORT startReg,
-    IN USHORT dataLength,
-    IN USHORT *ptrData)
-{
-    USHORT   index, reg;
-
-    TRACE ((LVL_ENTRY, "WriteBlockEEprom\n"));
-
-    for (index = 0, reg = startReg; index < dataLength; index++, reg++)
-    {
-         WriteEEprom(adapter, reg, ptrData[index]);
-    }
-
-
-}
-
 //----------------------------------------------------------------------------------------
 // Procedure:   WriteEEpromAndChecksum
 //
@@ -705,13 +544,9 @@ WriteBlockEEprom (
 //
 // Returns: (none)
 //----------------------------------------------------------------------------------------
-VOID
-WriteEEpromAndChecksum (
-    IN PD100_ADAPTER adapter,
-    IN USHORT reg,
-    IN USHORT data)
+void WriteEEpromAndChecksum(bd_config_t *adapter, __u16 reg, __u16 data)
 {
-    USHORT oldData = ReadEEprom(adapter, reg);
+    __u16 oldData = ReadEEprom(adapter, reg);
     
     WriteEEprom (adapter, reg, data);
     QuickUpdateChecksum (adapter, reg, oldData, data);
@@ -730,20 +565,16 @@ WriteEEpromAndChecksum (
 //      FALSE - If the command never finished (EEDO stayed low)
 //----------------------------------------------------------------------------------------
 
-USHORT
-WaitEEpromCmdDone (
-    IN PD100_ADAPTER adapter)
+__u16 WaitEEpromCmdDone(bd_config_t *adapter)
 {
-    USHORT  x, i;
-    TRACE ((LVL_ENTRY, "WaitEEpromCmdDone\n"));
+    __u16 x, i;
 
     StandBy (adapter);
-    for (i=0; i < 200; i++)
-    {
-        x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
+    for (i=0; i < 200; i++) {
+        x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
         if (x & EEDO)
             return TRUE;
-        StallExecutionMicro (STALL_TIME);
+        udelay (STALL_TIME);
     }
     
     return FALSE;
@@ -760,39 +591,18 @@ WaitEEpromCmdDone (
 // Returns: (none)
 //----------------------------------------------------------------------------------------
 
-VOID
-StandBy (
-    IN PD100_ADAPTER adapter)
+void StandBy(bd_config_t *adapter)
 {
-    USHORT  x;
-    TRACE ((LVL_ENTRY, "StandBy\n"));
+    __u16 x;
 
-    x = Csr_Read16 (adapter, CSR_EEPROM_CONTROL);
+    x = readw(&CSR_EEPROM_CONTROL_FIELD(adapter));
 
     x &= ~(EECS | EESK);
-    Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
+    writew(x, &CSR_EEPROM_CONTROL_FIELD(adapter));
 
-    StallExecutionMicro (4);
+    udelay(4);
     x |= EECS;
-    Csr_Write16 (adapter, CSR_EEPROM_CONTROL, x);
-    StallExecutionMicro (1);    
-}
-
-//----------------------------------------------------------------------------------------
-// Procedure:   EnableDebugMode
-//
-// Description:
-//
-// Arguments:
-//
-// Returns: (none)
-//----------------------------------------------------------------------------------------
-
-VOID
-EnableDebugMode (
-    IN PD100_ADAPTER adapter
-)
-{
-
+    writew(x, &CSR_EEPROM_CONTROL_FIELD(adapter));
+    udelay(1);    
 }
 
